# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.schedulable_message_type import SchedulableMessageType

class TestSchedulableMessageType(unittest.TestCase):
    """SchedulableMessageType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSchedulableMessageType(self):
        """Test SchedulableMessageType"""
        # inst = SchedulableMessageType()

if __name__ == '__main__':
    unittest.main()
